emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/git-commit 547ad9e393: Fix a single typo


From: ELPA Syncer
Subject: [nongnu] elpa/git-commit 547ad9e393: Fix a single typo
Date: Mon, 2 May 2022 18:58:06 -0400 (EDT)

branch: elpa/git-commit
commit 547ad9e39341c9a9dc37b2c88acb487d737a8e3b
Author: Jonas Bernoulli <jonas@bernoul.li>
Commit: Jonas Bernoulli <jonas@bernoul.li>

    Fix a single typo
    
    But it sure was copied to a lot of places. ;P
---
 docs/magit-section.org  | 6 +++---
 docs/magit-section.texi | 6 +++---
 lisp/magit-section.el   | 8 ++++----
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/docs/magit-section.org b/docs/magit-section.org
index 20397c3883..a75fa30145 100644
--- a/docs/magit-section.org
+++ b/docs/magit-section.org
@@ -152,7 +152,7 @@ source for suitable examples before asking me for help.  
Thanks!
   Return the section at point or where the context menu was invoked.
   When using the context menu, return the section that the user
   clicked on, provided the current buffer is the buffer in which
-  the click occured.  Otherwise return the section at point.
+  the click occurred.  Otherwise return the section at point.
 
 - Function magit-section-at &optional position ::
 
@@ -207,14 +207,14 @@ when appropriate.
   Return point or the position where the context menu was invoked.
   When using the context menu, return the position the user clicked
   on, provided the current buffer is the buffer in which the click
-  occured.  Otherwise return the same value as ~point~.
+  occurred.  Otherwise return the same value as ~point~.
 
 - Function magit-thing-at-point thing &optional no-properties ::
 
   Return the THING at point or where the context menu was invoked.
   When using the context menu, return the thing the user clicked
   on, provided the current buffer is the buffer in which the click
-  occured.  Otherwise return the same value as ~thing-at-point~.
+  occurred.  Otherwise return the same value as ~thing-at-point~.
   For the meaning of THING and NO-PROPERTIES see that function.
 
 * Matching Functions
diff --git a/docs/magit-section.texi b/docs/magit-section.texi
index 41fe361d97..029cfbf971 100644
--- a/docs/magit-section.texi
+++ b/docs/magit-section.texi
@@ -196,7 +196,7 @@ buffer is reached.  FUNCTION has to move point forward or 
return
 Return the section at point or where the context menu was invoked.
 When using the context menu, return the section that the user
 clicked on, provided the current buffer is the buffer in which
-the click occured.  Otherwise return the section at point.
+the click occurred.  Otherwise return the section at point.
 @end defun
 
 @table @asis
@@ -253,13 +253,13 @@ when appropriate.
 Return point or the position where the context menu was invoked.
 When using the context menu, return the position the user clicked
 on, provided the current buffer is the buffer in which the click
-occured.  Otherwise return the same value as @code{point}.
+occurred.  Otherwise return the same value as @code{point}.
 
 @item Function magit-thing-at-point thing &optional no-properties
 Return the THING at point or where the context menu was invoked.
 When using the context menu, return the thing the user clicked
 on, provided the current buffer is the buffer in which the click
-occured.  Otherwise return the same value as @code{thing-at-point}.
+occurred.  Otherwise return the same value as @code{thing-at-point}.
 For the meaning of THING and NO-PROPERTIES see that function.
 @end table
 
diff --git a/lisp/magit-section.el b/lisp/magit-section.el
index e5383ff424..239b3f4637 100644
--- a/lisp/magit-section.el
+++ b/lisp/magit-section.el
@@ -445,7 +445,7 @@ never modify it.")
   "Return point or the position where the context menu was invoked.
 When using the context menu, return the position the user clicked
 on, provided the current buffer is the buffer in which the click
-occured.  Otherwise return the same value as `point'."
+occurred.  Otherwise return the same value as `point'."
   (if magit--context-menu-section
       (magit-menu-position)
     (point)))
@@ -454,7 +454,7 @@ occured.  Otherwise return the same value as `point'."
   "Return the THING at point or where the context menu was invoked.
 When using the context menu, return the thing the user clicked
 on, provided the current buffer is the buffer in which the click
-occured.  Otherwise return the same value as `thing-at-point'.
+occurred.  Otherwise return the same value as `thing-at-point'.
 For the meaning of THING and NO-PROPERTIES see that function."
   (if-let ((pos (magit-menu-position)))
       (save-excursion
@@ -466,7 +466,7 @@ For the meaning of THING and NO-PROPERTIES see that 
function."
   "Return the section at point or where the context menu was invoked.
 When using the context menu, return the section that the user
 clicked on, provided the current buffer is the buffer in which
-the click occured.  Otherwise return the section at point."
+the click occurred.  Otherwise return the section at point."
   (or magit--context-menu-section
       (magit-section-at)
       magit-root-section))
@@ -634,7 +634,7 @@ the expression (magit-menu-format-desc DESC) for that.  See
   (define-key-after keymap key
     `( menu-item ,desc ,def ,@props
        ;; Without this, the keys for point would be shown instead
        ;; of the relevant ones from where the click occured.
        ,@(and (not (region-active-p))
               (list :keys
                     (lambda ()
@@ -634,7 +634,7 @@ the expression (magit-menu-format-desc DESC) for that.  See
     `( menu-item ,desc ,def ,@props
        ;; Without this, the keys for point would be shown instead
-       ;; of the relevant ones from where the click occured.
+       ;; of the relevant ones from where the click occurred.
        ,@(and (not (region-active-p))
               (list :keys



reply via email to

[Prev in Thread] Current Thread [Next in Thread]